@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    busy.h -- reiser4 busybox declarations. */
@@ -17,7 +17,6 @@
 #include <misc/misc.h>
 #include <reiser4/libreiser4.h>
 
-#define TESTS_COUNT (sizeof(tests) / sizeof(busy_cmd_t))
 #define PATH_MAXLEN 4096
 
 typedef struct busy_target {
@@ -26,6 +25,8 @@ typedef struct busy_target {
 	long long int offset;
 } busy_target_t;
 
+#define OBJFLAG_CRYCOM	(1 << 16)
+
 typedef struct busy_ctx {
 	int testno;
 	
