@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    rm.c -- a demo program that works similar to the standard rm utility. */
@@ -39,7 +39,7 @@ errno_t rm_cmd(busy_ctx_t *ctx) {
 		goto error_close_object;
 	}
 	
-	if (!plug_call(objplug(object)->o.object_ops, linked, object->ent)) {
+	if (!plugcall(reiser4_psobj(object), linked, object)) {
 		/* There are no other link to this object, destroy it. */
 		if (reiser4_object_clobber(object)) {
 			aal_error("Can't to erase the object %s.", 
