@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    flow.h -- declarations of functions for working with flow. */
@@ -18,8 +18,8 @@ extern int64_t reiser4_flow_write(reiser4_tree_t *tree,
 extern errno_t reiser4_flow_convert(reiser4_tree_t *tree,
 				    conv_hint_t *hint);
 
-extern int64_t reiser4_flow_truncate(reiser4_tree_t *tree,
-				     trans_hint_t *hint);
+extern int64_t reiser4_flow_cut(reiser4_tree_t *tree,
+				trans_hint_t *hint);
 #endif
 
 #endif
