@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    libreiser4.c -- version control functions, library initialization code and
@@ -13,8 +13,8 @@ const char *reiser4_igname[] = {
 	"DIRITEM",
 	"TAIL",
 	"EXTENT",
-	"PERM",
-	"SLINK"
+	"SLINK",
+	"CTAIL"
 };
 
 const char *reiser4_slink_name[] = {
@@ -47,9 +47,9 @@ static int64_t tree_write(tree_entity_t *tree, trans_hint_t *hint) {
 	return reiser4_flow_write((reiser4_tree_t *)tree, hint);
 }
 
-/* Handler for truncate operation from @core. */
-static int64_t tree_truncate(tree_entity_t *tree, trans_hint_t *hint) {
-	return reiser4_flow_truncate((reiser4_tree_t *)tree, hint);
+/* Handler for cut operation from @core. */
+static int64_t tree_cut(tree_entity_t *tree, trans_hint_t *hint) {
+	return reiser4_flow_cut((reiser4_tree_t *)tree, hint);
 }
 
 /* Handler for item removing requests from all plugins. */
@@ -87,8 +87,12 @@ static errno_t tree_next_item(tree_entity_t *tree, reiser4_place_t *place,
 	return reiser4_tree_next_place((reiser4_tree_t *)tree, place, next);
 }
 
-static reiser4_plug_t *pset_find(rid_t member, rid_t id) {
-	return reiser4_opset_plug(member, id);
+static errno_t tree_mpressure(tree_entity_t *tree) {
+	return reiser4_tree_mpressure((reiser4_tree_t *)tree);
+}
+
+static reiser4_plug_t *pset_find(rid_t member, rid_t id, int is_pset) {
+	return reiser4_pset_find(member, id, is_pset);
 }
 
 #ifndef ENABLE_MINIMAL
@@ -112,8 +116,8 @@ static errno_t tree_convert(tree_entity_t *tree, conv_hint_t *hint) {
 	return reiser4_flow_convert((reiser4_tree_t *)tree, hint);
 }
 
-static void pset_diff(tree_entity_t *tree, reiser4_opset_t *opset) {
-	reiser4_opset_diff((reiser4_tree_t *)tree, opset);
+static uint64_t pset_build_mask(tree_entity_t *tree, reiser4_pset_t *pset) {
+	return reiser4_pset_build_mask((reiser4_tree_t *)tree, pset);
 }
 
 static int item_mergeable(reiser4_place_t *place1,
@@ -129,8 +133,7 @@ static uint64_t tree_slink_locality(tree_entity_t *tree) {
 	aal_assert("vpf-1580", t->fs != NULL);
 	aal_assert("vpf-1581", t->fs->oid != NULL);
 	
-	return plug_call(t->fs->oid->ent->plug->o.oid_ops, 
-			 slink_locality);
+	return plugcall(t->fs->oid->ent->plug, slink_locality);
 }
 
 static errno_t tree_inc_free(tree_entity_t *tree, count_t count) {
@@ -166,7 +169,7 @@ static errno_t object_resolve(tree_entity_t *tree, char *path,
 		return -EINVAL;
 
 	/* Save object stat data key to passed @key. */
-	aal_memcpy(key, &object->ent->object, sizeof(*key));
+	aal_memcpy(key, &object->info.object, sizeof(*key));
 
 	/* Close found object. */
 	reiser4_object_close(object);
@@ -185,7 +188,7 @@ reiser4_core_t core = {
 		
 #ifndef ENABLE_MINIMAL
 		/* Callback for truncating data in tree. */
-		.truncate	= tree_truncate,
+		.cut		= tree_cut,
 
 		/*Convertion to another item plugin. */
 		.convert	= tree_convert,
@@ -219,7 +222,9 @@ reiser4_core_t core = {
 		.dec_free	= tree_dec_free,
 #endif
 		/* Returns next item from the passed place. */
-		.next_item	= tree_next_item
+		.next_item	= tree_next_item,
+
+		.mpressure	= tree_mpressure,
 	},
 	.factory_ops = {
 		/* search a plugin by its type and id. */
@@ -228,7 +233,7 @@ reiser4_core_t core = {
 	.pset_ops = {
 		.find		= pset_find,
 #ifndef ENABLE_MINIMAL
-		.diff		= pset_diff,
+		.build_mask	= pset_build_mask,
 #endif
 	},
 #ifdef ENABLE_SYMLINKS
