@@ -1,4 +1,4 @@
-/* Copyright 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by 
+/* Copyright 2001-2005 by Hans Reiser, licensing governed by 
    reiser4progs/COPYING.
    
    librepair/filter.c - Filter pass of file system recovery.
@@ -213,8 +213,10 @@ static reiser4_node_t *repair_filter_node_open(reiser4_tree_t *tree,
 	
 	if (blk >= fd->bm_used->total) {
 		fsck_mess("Node (%llu), item (%u), unit (%u): Points to the "
-			  "invalid block (%llu).%s", place_blknr(place),
-			  place->pos.item, place->pos.unit, blk, 
+			  "invalid block (%llu).%s",
+			  (unsigned long long)place_blknr(place),
+			  place->pos.item, place->pos.unit,
+			  (unsigned long long)blk, 
 			  fd->repair->mode == RM_BUILD ? " Removed." :
 			  " The whole subtree is skipped.");
 		error = 1;
@@ -222,10 +224,13 @@ static reiser4_node_t *repair_filter_node_open(reiser4_tree_t *tree,
 	
 	if (reiser4_bitmap_test_region(fd->bm_used, blk, 1, 1)) {
 		/* Bad pointer detected. Remove if possible. */
-		fsck_mess("Node (%llu), item (%u), unit (%u): Points to the "
+		fsck_mess("Node (blk %llu, lev %d) points (item %u, unit %u) to the "
 			  "block (%llu) which is in the tree already.%s", 
-			  place_blknr(place), place->pos.item, 
-			  place->pos.unit, blk, fd->repair->mode == RM_BUILD ?
+			  (unsigned long long)place_blknr(place),
+			  reiser4_node_get_level(place->node),
+			  place->pos.item, place->pos.unit,
+			  (unsigned long long)blk,
+			  fd->repair->mode == RM_BUILD ?
 			  " Removed." : " The whole subtree is skipped.");
 		error = 1;
 	}
@@ -235,11 +240,13 @@ static reiser4_node_t *repair_filter_node_open(reiser4_tree_t *tree,
 	if (!(node = repair_tree_load_node(fd->repair->fs->tree, place->node, 
 					   blk, fd->mkidok ? fd->mkid : 0)))
 	{
-		fsck_mess("Node (%llu): failed to open the node pointed by the "
-			  "node (%llu), item (%u), unit (%u) on the level (%u)."
-			  " The whole subtree is skipped.", blk, 
-			  place_blknr(place), place->pos.item, 
-			  place->pos.unit, reiser4_node_get_level(place->node));
+		fsck_mess("Node (blk %llu, lev %d) points (item %u, unit %u) "
+			  "to block %llu which could not be open."
+			  " Whole subtree is skipped.", 
+			  (unsigned long long)place_blknr(place),
+			  reiser4_node_get_level(place->node),
+			  place->pos.item, place->pos.unit,
+			  (unsigned long long)blk);
 		goto error;
 	}
 	
@@ -254,7 +261,7 @@ static reiser4_node_t *repair_filter_node_open(reiser4_tree_t *tree,
 static errno_t cb_count_sd(reiser4_place_t *place, void *data) {
 	repair_filter_t *fd = (repair_filter_t *)data;
 
-	if (place->plug->id.group == STAT_ITEM)
+	if (place->plug->p.id.group == STAT_ITEM)
 		fd->stat.tmp++;
 
 	return 0;
@@ -284,9 +291,10 @@ static errno_t repair_filter_node_check(reiser4_node_t *node, void *data) {
 
 	/* Check the level. */
 	if (fd->level != level) {
-		fsck_mess("Level (%u) of the node (%llu) doesn't match the "
-			  "expected one (%u). %s", level, node->block->nr, 
-			  fd->level, fd->repair->mode == RM_BUILD ? 
+		fsck_mess("Node (blk %llu, lev %d) does not match the "
+			  "expected one (%u). %s",
+			  (unsigned long long)node->block->nr, level,
+			  fd->level, fd->repair->mode == RM_BUILD ?
 			  "Removed." : "The whole subtree is skipped.");
 		
 		/* Should not be check for now as it may lie in unused space.
@@ -371,7 +379,8 @@ static errno_t repair_filter_update_traverse(reiser4_place_t *place,
 
 	if ((blk = reiser4_item_down_link(place)) == INVAL_BLK) {
 		aal_error("Node (%llu), item (%u), unit(%u): Failed to "
-			  "fetch the node pointer.", place_blknr(place),
+			  "fetch the node pointer.",
+			  (unsigned long long)place_blknr(place),
 			  place->pos.item, place->pos.unit);
 		return -EIO;
 	}
@@ -381,7 +390,8 @@ static errno_t repair_filter_update_traverse(reiser4_place_t *place,
 	   from the parent to avoid futher problems with poitners to this node
 	   from other parents. */
 	if ((node = reiser4_tree_lookup_node(tree, blk)) &&
-	    node->p.node->block->nr == place->node->block->nr)
+	    (node->p.node &&
+	     node->p.node->block->nr == place->node->block->nr))
 	{
 		if ((res = reiser4_tree_disconnect_node(tree, node)))
 			return -EINVAL;
@@ -398,20 +408,25 @@ static errno_t repair_filter_update_traverse(reiser4_place_t *place,
 	if ((fd->flags & RE_FATAL) || (fd->flags & RE_EMPTY)) {
 		fsck_mess("Node (%llu): the node is %s. Pointed from "
 			  "the node (%llu), item (%u), unit (%u). %s",
-			  blk, fd->flags & RE_EMPTY ? "empty" :
-			  fd->repair->mode == RM_BUILD ? "unrecoverable" : 
-			  "broken", place_blknr(place), place->pos.item,
-			  place->pos.unit, fd->repair->mode == RM_BUILD ? 
+			  (unsigned long long)blk,
+			  fd->flags & RE_EMPTY ? "empty" :
+			  fd->repair->mode == RM_BUILD ? "unrecoverable" :
+			  "broken",
+			  (unsigned long long)place_blknr(place),
+			  place->pos.item,
+			  place->pos.unit, fd->repair->mode == RM_BUILD ?
 			  "Removed." : "The whole subtree is skipped.");
 	} else if (fd->flags & RE_DKEYS) {
-		fsck_mess("Node (%llu), item (%u), unit (%u): Points to "
+		fsck_mess("Node (blk %llu, lev %d) points (item %u, unit %u) to "
 			  "the node [%llu] with wrong delimiting keys. %s",
-			  place_blknr(place), place->pos.item, 
-			  place->pos.unit, blk, fd->repair->mode == RM_BUILD ?
+			  (unsigned long long)place_blknr(place),
+			  reiser4_node_get_level(place->node),
+			  place->pos.item, place->pos.unit,
+			  (unsigned long long)blk,
+			  fd->repair->mode == RM_BUILD ?
 			  "Removed, content will be inserted later item-by-"
 			  "item." : "The whole subtree is skipped.");
 	}
-	
 	if (fd->repair->mode == RM_BUILD) {
 		pos_t prev;
 		trans_hint_t hint;
@@ -481,7 +496,7 @@ static void repair_filter_update(repair_filter_t *fd) {
 		
 		if (!(fd->flags & RE_PTR)) {
 			fsck_mess("Root node (%llu): the node is %s. %s",
-				  reiser4_format_get_root(format), 
+				  (unsigned long long)reiser4_format_get_root(format),
 				  fd->flags & RE_EMPTY ? "empty" :
 				  fd->repair->mode == RM_BUILD ? 
 				  "unrecoverable" : "broken",
@@ -620,7 +635,8 @@ static errno_t repair_filter_traverse(repair_filter_t *fd) {
 	
 	if (!tree->root) {
 		fsck_mess("Node (%llu): failed to open the root node. "
-			  "The whole filter pass is skipped.", root);
+			  "The whole filter pass is skipped.",
+			  (unsigned long long)root);
 		
 		goto error;
 	}
@@ -656,7 +672,7 @@ errno_t repair_filter(repair_filter_t *fd) {
 	aal_assert("vpf-816", fd->repair->fs->tree != NULL);
 	aal_assert("vpf-815", fd->bm_used != NULL);
 
-	aal_mess("CHECKING STORAGE TREE");
+	aal_mess("CHECKING THE STORAGE TREE");
 	fd->gauge = aal_gauge_create(aux_gauge_handlers[GT_PROGRESS], 
 				     cb_gauge_tree_percent, NULL, 500, NULL);
 	time(&fd->stat.time);
