@@ -1,4 +1,4 @@
-/* Copyright 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by 
+/* Copyright 2001-2005 by Hans Reiser, licensing governed by 
    reiser4progs/COPYING.
    
    librepair/repair.c - control methods for broken filesystem recovery. */
@@ -58,11 +58,12 @@ static errno_t repair_bitmap_compare(reiser4_bitmap_t *bm1,
 
 					if (!verbose)
 						continue;
-					
+
 					fprintf(stderr, "Block (%llu) is %s "
 						"in on-disk bitmap, should "
-						"be not.\n", i, 
-						reiser4_bitmap_test(bm1, i) ? 
+						"be not.\n",
+						(unsigned long long)i, 
+						reiser4_bitmap_test(bm1, i) ?
 						"marked" : "free");
 				}
 			}
@@ -82,13 +83,12 @@ static errno_t repair_bitmap_compare(reiser4_bitmap_t *bm1,
 				continue;
 
 			fprintf(stderr, "Block (%llu) is %s in on-disk "
-				"bitmap, should be not.\n", i, 
+				"bitmap, should be not.\n",
+				(unsigned long long)i,
 				reiser4_bitmap_test(bm1, i) ?
 				"marked" : "free");
 		}
 	}
-	
-
 	return diff;
 }
 
@@ -532,9 +532,8 @@ static errno_t repair_sem_prepare(repair_control_t *control,
 }
 
 static errno_t repair_sem_fini(repair_control_t *control, 
-			       repair_semantic_t *sem) {
-	uint64_t fs_len;
-
+			       repair_semantic_t *sem)
+{
 	control->oid = sem->stat.oid + 1;
 	control->files = sem->stat.reached_files;
 	
@@ -542,23 +541,19 @@ static errno_t repair_sem_fini(repair_control_t *control,
 	if (control->repair->mode == RM_BUILD)
 		return 0;
 	
-	fs_len = reiser4_format_get_len(control->repair->fs->format);
-	
 	if (repair_bitmap_compare(control->bm_alloc, control->bm_used, 0)) {
-		fsck_mess("On-disk used blocks and really used blocks "
-			  "differ.%s", control->repair->mode == RM_FIX &&
-			  !control->repair->fatal ? " Fixed." : "");
+		fsck_mess("On-disk used block bitmap and really used block "
+			  "bitmap differ.%s", control->repair->mode == RM_BUILD 
+			  ? " Fixed." : "");
 
-		if (control->repair->mode == RM_FIX && 
-		    !control->repair->fatal)
-		{
+		if (control->repair->mode == RM_BUILD) {
 			/* Assign the bm_used bitmap to the block allocator. */
 			reiser4_alloc_assign(control->repair->fs->alloc, 
 					     control->bm_used);
 
 			reiser4_alloc_sync(control->repair->fs->alloc);
 		} else 
-			control->repair->fixable++;
+			control->repair->fatal++;
 	}
 
 	reiser4_bitmap_close(control->bm_alloc);
@@ -639,8 +634,10 @@ static errno_t repair_update(repair_control_t *control) {
 	if (correct != val) {
 		if (mode != RM_BUILD) {
 			fsck_mess("Free block count %llu found in the format is "
-				  "wrong. %s %llu.", val, mode == RM_CHECK ? 
-				  "Should be" : "Fixed to", correct);
+				  "wrong. %s %llu.",
+				  (unsigned long long)val,
+				  mode == RM_CHECK ? "Should be" : "Fixed to",
+				  (unsigned long long)correct);
 		}
 
 		if (mode != RM_CHECK)
@@ -657,13 +654,13 @@ static errno_t repair_update(repair_control_t *control) {
 	if (control->oid && control->oid > val) {
 		if (mode != RM_BUILD) {
 			fsck_mess("First not used oid %llu is wrong. %s %llu.",
-				  val, mode == RM_CHECK ? "Should be" : 
-				  "Fixed to", control->oid);
+				  (unsigned long long)val,
+				  mode == RM_CHECK ? "Should be" : "Fixed to",
+				  (unsigned long long)control->oid);
 		}
 
 		if (mode != RM_CHECK) {
-			plug_call(fs->oid->ent->plug->o.oid_ops, set_next,
-				  fs->oid->ent, control->oid);
+			reiser4call(fs->oid, set_next, control->oid);
 		} else {
 			control->repair->fixable++;
 		}
@@ -676,8 +673,9 @@ static errno_t repair_update(repair_control_t *control) {
 
 		if (control->files && control->files != val) {
 			fsck_mess("File count %llu is wrong. %s %llu.",
-				  val, mode != RM_BUILD ? "Should be" : 
-				  "Fixed to", control->files);
+				  (unsigned long long)val,
+				  mode != RM_BUILD ? "Should be" : "Fixed to",
+				  (unsigned long long)control->files);
 
 			if (mode == RM_BUILD)
 				reiser4_oid_set_used(fs->oid, control->files);
@@ -792,8 +790,14 @@ errno_t repair_check(repair_data_t *repair) {
 	if (repair->fatal) {
 		aal_warn("Fatal corruptions were found. "
 			 "Semantic pass is skipped.");
+		/*
+		 * We need to prepare pset for backup
+		 * creation in fsck_check_fini().
+		 */
+		if ((res = reiser4_pset_tree(control.repair->fs->tree, 0)))
+			goto error;
 		goto update;
-	} 
+	}
 	
 	/* Check the semantic reiser4 tree. */
 	if ((res = repair_sem_prepare(&control, &sem)))
