@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    stat40.c -- reiser4 stat data plugin. */
@@ -7,7 +7,7 @@
 #include "stat40_repair.h"
 #include <sys/stat.h>
 
-reiser4_core_t *stat40_core;
+reiser4_core_t *stat40_core = NULL;
 
 /* The function which implements stat40 layout pass. This function is used for
    all statdata extension-related actions. For example for reading, or
@@ -44,15 +44,14 @@ errno_t stat40_traverse(reiser4_place_t *place,
 			
 			extmask = st40_get_extmask(stat_body(&stat));
 			
-			stat.ext_plug = NULL;
+			stat.plug = NULL;
 			
 			/* Call the callback for every read extmask. */
-			if ((res = ext_func(&stat, extmask << (chunks * 16),
-					    data)))
-				return res;
-
+			res = ext_func(&stat, extmask << (chunks * 16), data);
+			if (res) return res;
+			
 			chunks++;
-			stat.offset += sizeof(d16_t);
+			stat.offset += sizeof(stat40_t);
 
 			if (i > 0) continue;
 		}
@@ -62,18 +61,21 @@ errno_t stat40_traverse(reiser4_place_t *place,
 			continue;
 
 		/* Getting extension plugin from the plugin factory */
-		stat.ext_plug = stat40_core->factory_ops.ifind(SDEXT_PLUG_TYPE,i);
+		stat.plug = (reiser4_sdext_plug_t *)
+			stat40_core->factory_ops.ifind(SDEXT_PLUG_TYPE,i);
 		
-		if (!stat.ext_plug)
+		if (!stat.plug)
 			continue;
 		
 		/* Call the callback for every found extension. */
 		if ((res = ext_func(&stat, extmask, data)))
 			return res;
-		
+
+		if (stat.plug->info)
+			stat.plug->info(&stat);
+
 		/* Calculating the pointer to the next extension body */
-		stat.offset += plug_call(stat.ext_plug->o.sdext_ops, 
-					 length, &stat, NULL);
+		stat.offset += objcall(&stat, length, NULL);
 	}
  
 	return 0;
@@ -87,62 +89,66 @@ static errno_t cb_open_ext(stat_entity_t *stat, uint64_t extmask, void *data) {
 	/* Method open is not defined, this probably means, we only interested
 	   in symlink's length method in order to reach other symlinks body. So,
 	   we retrun 0 here. */
-	if (!stat->ext_plug || !stat->ext_plug->o.sdext_ops->open)
+	if (!stat->plug || !stat->plug->open)
 		return 0;
 	
 	hint = (trans_hint_t *)data;
 	stath = hint->specific;
 
 	/* Reading mask into hint */
-	stath->extmask |= ((uint64_t)1 << stat->ext_plug->id.id);
+	stath->extmask |= ((uint64_t)1 << stat->plug->p.id.id);
 
 	/* We load @ext if its hint present in @stath */
-	if (stath->ext[stat->ext_plug->id.id]) {
-		void *sdext = stath->ext[stat->ext_plug->id.id];
+	if (stath->ext[stat->plug->p.id.id]) {
+		void *sdext = stath->ext[stat->plug->p.id.id];
 
-		return plug_call(stat->ext_plug->o.sdext_ops, 
-				 open, stat, sdext);
+		return objcall(stat, open, sdext);
 	}
 	
 	return 0;
 }
 
-static inline reiser4_plug_t *stat40_modeplug(tree_entity_t *tree, 
-					      uint16_t mode) 
+static inline reiser4_plug_t *stat40_file_mode(tree_entity_t *tree, 
+					       uint16_t mode) 
 {
 	if (S_ISLNK(mode))
-		return tree->opset[OPSET_SYMLINK];
+		return tree->tset[TSET_SYMFILE];
 	else if (S_ISREG(mode))
-		return tree->opset[OPSET_CREATE];
+		return tree->tset[TSET_REGFILE];
 	else if (S_ISDIR(mode))
-		return tree->opset[OPSET_MKDIR];
+		return tree->tset[TSET_DIRFILE];
 	else if (S_ISCHR(mode))
-		return tree->opset[OPSET_MKNODE];
+		return tree->tset[TSET_SPLFILE];
 	else if (S_ISBLK(mode))
-		return tree->opset[OPSET_MKNODE];
+		return tree->tset[TSET_SPLFILE];
 	else if (S_ISFIFO(mode))
-		return tree->opset[OPSET_MKNODE];
+		return tree->tset[TSET_SPLFILE];
 	else if (S_ISSOCK(mode))
-		return tree->opset[OPSET_MKNODE];
+		return tree->tset[TSET_SPLFILE];
 
 	return NULL;
 }
 
+static inline reiser4_plug_t *stat40_dir_mode(tree_entity_t *tree, 
+					      uint16_t mode) 
+{
+	return NULL;
+}
+
 /* Decodes the object plug from the mode if needed. */
-static void stat40_decode_opset(tree_entity_t *tree,
-				sdhint_plug_t *plugh, 
-				sdhint_lw_t *lwh) 
+static void stat40_decode_pset(tree_entity_t *tree,
+			       sdhint_plug_t *plugh,
+			       sdhint_lw_t *lwh)
 {
 	aal_assert("vpf-1630", tree != NULL);
 	aal_assert("vpf-1631", plugh != NULL);
 	aal_assert("vpf-1632", lwh != NULL);
 	
 	/* Object plugin does not need to be set. */
-	if (plugh->plug[OPSET_OBJ])
-		return;
-
-	plugh->plug[OPSET_OBJ] = stat40_modeplug(tree, lwh->mode);
-	plugh->mask |= (1 << OPSET_OBJ);
+	if (!plugh->plug[PSET_OBJ]) {
+		plugh->plug[PSET_OBJ] = stat40_file_mode(tree, lwh->mode);
+		plugh->plug_mask |= (1 << PSET_OBJ);
+	}
 }
 
 /* Fetches whole statdata item with extensions into passed @buff */
@@ -154,11 +160,11 @@ static int64_t stat40_fetch_units(reiser4_place_t *place, trans_hint_t *hint) {
 	aal_assert("umka-1415", hint != NULL);
 	aal_assert("umka-1414", place != NULL);
 	aal_assert("vpf-1633", place->node != NULL);
-
+	
 	exts = ((stat_hint_t *)hint->specific)->ext;
 	
-	/* If plug_hint is fetched, lw is needed also to adjust OPSET_OBJ. */
-	if (exts[SDEXT_PLUG_ID]) {
+	/* If plug_hint is fetched, lw is needed also to adjust PSET_OBJ. */
+	if (exts[SDEXT_PSET_ID]) {
 		if (!exts[SDEXT_LW_ID]) {
 			exts[SDEXT_LW_ID] = &lwh;
 			lw_local = 1;
@@ -167,18 +173,16 @@ static int64_t stat40_fetch_units(reiser4_place_t *place, trans_hint_t *hint) {
 	
 	if (stat40_traverse(place, cb_open_ext, hint))
 		return -EINVAL;
-
-	/* Adjust OPSET_OBJ. */
-	if (exts[SDEXT_PLUG_ID]) {
-		stat40_decode_opset(place->node->tree,
-				    (sdhint_plug_t *)exts[SDEXT_PLUG_ID],
+	
+	/* Adjust PSET_OBJ. */
+	if (exts[SDEXT_PSET_ID]) {
+		stat40_decode_pset(place->node->tree,
+				    (sdhint_plug_t *)exts[SDEXT_PSET_ID],
 				    (sdhint_lw_t *)exts[SDEXT_LW_ID]);
+		if (lw_local)
+			exts[SDEXT_LW_ID] = NULL;
 	}
-	
-	if (lw_local) {
-		exts[SDEXT_LW_ID] = NULL;
-	}
-	
+
 	return 1;
 }
 
@@ -191,12 +195,11 @@ static uint32_t stat40_units(reiser4_place_t *place) {
 }
 
 #ifndef ENABLE_MINIMAL
-
-static errno_t stat40_encode_opset(reiser4_place_t *place, trans_hint_t *hint) {
+static errno_t stat40_encode_pset(reiser4_place_t *place, trans_hint_t *hint) {
+	stat_hint_t *sd_hint;
 	sdhint_plug_t *plugh;
 	tree_entity_t *tree;
 	uint16_t mode;
-	void **exts;
 	errno_t res;
 	
 	aal_assert("vpf-1634", hint != NULL);
@@ -206,14 +209,14 @@ static errno_t stat40_encode_opset(reiser4_place_t *place, trans_hint_t *hint) {
 	if (!hint->specific || !((stat_hint_t *)hint->specific)->ext)
 		return 0;
 	
-	exts = ((stat_hint_t *)hint->specific)->ext;
-	plugh = ((sdhint_plug_t *)exts[SDEXT_PLUG_ID]);
+	sd_hint = (stat_hint_t *)hint->specific;
+	plugh = ((sdhint_plug_t *)sd_hint->ext[SDEXT_PSET_ID]);
 	
-	if (!plugh || !plugh->plug[OPSET_OBJ])
+	if (!plugh || !(plugh->plug_mask & (1 << PSET_OBJ)))
 		return 0;
 	
 	/* If LW hint is not present, fetch it from disk. */
-	if (!exts[SDEXT_LW_ID]) {
+	if (!sd_hint->ext[SDEXT_LW_ID]) {
 		trans_hint_t trans;
 		stat_hint_t stat;
 		sdhint_lw_t lwh;
@@ -229,19 +232,25 @@ static errno_t stat40_encode_opset(reiser4_place_t *place, trans_hint_t *hint) {
 		/* If there is no LW extention at all, nothing to encode. */
 		if (!(stat.extmask & (1 << SDEXT_LW_ID)))
 			return 0;
-			
+		
 		mode = lwh.mode;
 	} else {
-		mode = ((sdhint_lw_t *)exts[SDEXT_LW_ID])->mode;
+		mode = ((sdhint_lw_t *)sd_hint->ext[SDEXT_LW_ID])->mode;
 	}
-
+	
 	tree = place->node->tree;
 	
-	if (plugh->plug[OPSET_OBJ] == stat40_modeplug(tree, mode)) {
-		plugh->plug[OPSET_OBJ] = NULL;
-		plugh->mask &= ~(1 << OPSET_OBJ);
-	}
-
+	/* These all is performed on plugh hint, not on the object. So this 
+	   altered plug_mask will not be reflected in the object plug_mask. */
+	if (plugh->plug[PSET_OBJ] == stat40_file_mode(tree, mode))
+		plugh->plug_mask &= ~(1 << PSET_OBJ);
+	
+	plugh->plug_mask &= ~(1 << PSET_DIR);
+	
+	/* Throw away the SD_PLUG if mask is empty. */
+	if (!plugh->plug_mask)
+		sd_hint->extmask &= ~(1 << SDEXT_PSET_ID);
+	
 	return 0;
 }
 
@@ -256,7 +265,7 @@ static errno_t stat40_prep_insert(reiser4_place_t *place, trans_hint_t *hint) {
 
 	hint->len = 0;
 	
-	if ((res = stat40_encode_opset(place, hint)))
+	if ((res = stat40_encode_pset(place, hint)))
 		return res;
 	
 	if (place->pos.unit == MAX_UINT32)
@@ -268,7 +277,7 @@ static errno_t stat40_prep_insert(reiser4_place_t *place, trans_hint_t *hint) {
     
 	/* Estimating the all stat data extensions */
 	for (i = 0; i < STAT40_EXTNR; i++) {
-		reiser4_plug_t *plug;
+		reiser4_sdext_plug_t *plug;
 
 		/* Check if extension is present in mask */
 		if (!(((uint64_t)1 << i) & stath->extmask))
@@ -280,12 +289,15 @@ static errno_t stat40_prep_insert(reiser4_place_t *place, trans_hint_t *hint) {
 		   has 16 bits) then we add to hint's len the size of next
 		   mask. */
 		if ((i + 1) % 16 == 0) {
-			hint->len += sizeof(d16_t);
+			hint->len += sizeof(stat40_t);
 			continue;
 		}
 
 		/* Getting extension plugin */
-		if (!(plug = stat40_core->factory_ops.ifind(SDEXT_PLUG_TYPE, i))) {
+		plug = (reiser4_sdext_plug_t *)
+			stat40_core->factory_ops.ifind(SDEXT_PLUG_TYPE, i);
+		
+		if (!plug) {
 			aal_error("Can't find stat data extension plugin "
 				  "by its id 0x%x.", i);
 			return -EINVAL;
@@ -293,8 +305,7 @@ static errno_t stat40_prep_insert(reiser4_place_t *place, trans_hint_t *hint) {
 
 		/* Calculating length of the corresponding extension and add it
 		   to the estimated value. */
-		hint->len += plug_call(plug->o.sdext_ops, length, 
-				       NULL, stath->ext[i]);
+		hint->len += plugcall(plug, length, NULL, stath->ext[i]);
 	}
 	
 	return 0;
@@ -305,6 +316,7 @@ static int64_t stat40_modify(reiser4_place_t *place, trans_hint_t *hint, int ins
 	stat_hint_t *stath;
 	stat_entity_t stat;
 	uint16_t extmask = 0;
+	uint16_t chunks = 0;
 	uint16_t i;
 	
 	stath = (stat_hint_t *)hint->specific;
@@ -320,8 +332,6 @@ static int64_t stat40_modify(reiser4_place_t *place, trans_hint_t *hint, int ins
 		return 0;
     
 	for (i = 0; i < STAT40_EXTNR; i++) {
-		reiser4_plug_t *plug;
-	    
 		/* Stat data contains 16 bit mask of extensions used in it. The
 		   first 15 bits of the mask denote the first 15 extensions in
 		   the stat data. And the bit number is the stat data extension
@@ -351,17 +361,21 @@ static int64_t stat40_modify(reiser4_place_t *place, trans_hint_t *hint, int ins
 				st40_set_extmask(stat_body(&stat), extmask);
 			}
 			
-			stat.offset += sizeof(d16_t);
+			chunks++;
+			stat.offset += sizeof(stat40_t);
 
 			if (i > 0) continue;
 		}
 
 		/* Check if extension is present in mask */
-		if (!(((uint64_t)1 << i) & extmask))
+		if (!((1 << (i << (chunks - 1) * 16)) & extmask))
 			continue;
 
 		/* Getting extension plugin by extent number. */
-		if (!(plug = stat40_core->factory_ops.ifind(SDEXT_PLUG_TYPE, i))) {
+		stat.plug = (reiser4_sdext_plug_t *)
+			stat40_core->factory_ops.ifind(SDEXT_PLUG_TYPE, i);
+		
+		if (!stat.plug) {
 			aal_error("Can't find stat data extension plugin "
 				  "by its id 0x%x.", i);
 			return -EINVAL;
@@ -374,8 +388,8 @@ static int64_t stat40_modify(reiser4_place_t *place, trans_hint_t *hint, int ins
 
 				/* Moving the rest of stat data to the right 
 				   to keep stat data extension packed. */
-				extsize = plug_call(plug->o.sdext_ops, length,
-						    NULL, stath->ext[i]);
+				extsize = plugcall(stat.plug, length, NULL,
+						   stath->ext[i]);
 
 				aal_memmove(stat_body(&stat) + extsize, 
 					    stat_body(&stat), place->len -
@@ -383,14 +397,15 @@ static int64_t stat40_modify(reiser4_place_t *place, trans_hint_t *hint, int ins
 
 			}
 			
-			plug_call(plug->o.sdext_ops, init, 
-				  &stat, stath->ext[i]);
+			objcall(&stat, init, stath->ext[i]);
 		}
 
+		if (stat.plug->info)
+			stat.plug->info(&stat);
+		
 		/* Getting pointer to the next extension. It is evaluating as
 		   the previous pointer plus its size. */
-		stat.offset += plug_call(plug->o.sdext_ops, 
-					 length, &stat, NULL);
+		stat.offset += objcall(&stat, length, NULL);
 	}
     
 	place_mkdirty(place);
@@ -416,7 +431,6 @@ static int64_t stat40_update_units(reiser4_place_t *place, trans_hint_t *hint) {
 /* Removes stat data extensions marked in passed hint stat data extensions
    mask. Needed for fsck. */
 static errno_t stat40_remove_units(reiser4_place_t *place, trans_hint_t *hint) {
-	reiser4_plug_t *plug;
 	uint16_t old_extmask = 0;
 	uint16_t new_extmask;
 	uint16_t extsize;
@@ -461,23 +475,26 @@ static errno_t stat40_remove_units(reiser4_place_t *place, trans_hint_t *hint) {
 			st40_set_extmask(stat_body(&stat), new_extmask);
 				
 			chunks++;
-			stat.offset += sizeof(d16_t);
+			stat.offset += sizeof(stat40_t);
 
 			if (i > 0) continue;
 		}
 
 		/* Check if we're interested in this extension. */
-		if (!(((uint64_t)1 << i) & old_extmask))
+		if (!((1 << (i - (chunks - 1) * 16)) & old_extmask))
 			continue;
 
 		/* Getting extension plugin by extent number. */
-		if (!(plug = stat40_core->factory_ops.ifind(SDEXT_PLUG_TYPE, i))) {
+		stat.plug = (reiser4_sdext_plug_t *)
+			stat40_core->factory_ops.ifind(SDEXT_PLUG_TYPE, i);
+		
+		if (!stat.plug) {
 			aal_error("Can't find stat data extension plugin "
 				 "by its id 0x%x.", i);
 			return -EINVAL;
 		}
 
-		extsize = plug_call(plug->o.sdext_ops, length, &stat, NULL);
+		extsize = objcall(&stat, length, NULL);
 		
 		if ((((uint64_t)1 << i) & stath->extmask)) {
 			/* Moving the rest of stat data to left in odrer to 
@@ -490,6 +507,9 @@ static errno_t stat40_remove_units(reiser4_place_t *place, trans_hint_t *hint) {
 		} else {
 			/* Setting pointer to the next extension. */
 			stat.offset += extsize;
+
+			if (stat.plug->info)
+				stat.plug->info(&stat);
 		}
 	}
 	
@@ -508,7 +528,9 @@ static item_balance_ops_t balance_ops = {
 	.maxreal_key	  = NULL,
 	.mergeable	  = NULL,
 	.collision	  = NULL,
+	.overhead	  = NULL,
 #endif
+	.init		  = NULL,
 	.lookup		  = NULL,
 	.fetch_key	  = NULL,
 	.maxposs_key	  = NULL,
@@ -532,7 +554,6 @@ static item_object_ops_t object_ops = {
 	.layout		  = NULL,
 	.size		  = NULL,
 	.bytes		  = NULL,
-	.overhead	  = NULL,
 #endif
 	.fetch_units	  = stat40_fetch_units
 };
@@ -554,40 +575,20 @@ static item_debug_ops_t debug_ops = {
 };
 #endif
 
-static item_tree_ops_t tree_ops = {
-	.init		  = NULL,
-	.down_link	  = NULL,
+reiser4_item_plug_t stat40_plug = {
+	.p = {
+		.id    = {ITEM_STAT40_ID, STAT_ITEM, ITEM_PLUG_TYPE},
 #ifndef ENABLE_MINIMAL
-	.update_link	  = NULL
+		.label = "stat40",
+		.desc  = "StatData item plugin.",
 #endif
-};
+	},
 
-static reiser4_item_ops_t stat40_ops = {
-	.tree		  = &tree_ops,
 	.object		  = &object_ops,
 	.balance	  = &balance_ops,
 #ifndef ENABLE_MINIMAL
 	.repair		  = &repair_ops,
 	.debug		  = &debug_ops,
 #endif
+
 };
-
-static reiser4_plug_t stat40_plug = {
-	.cl    = class_init,
-	.id    = {ITEM_STAT40_ID, STAT_ITEM, ITEM_PLUG_TYPE},
-#ifndef ENABLE_MINIMAL
-	.label = "stat40",
-	.desc  = "Stat data item for reiser4. ",
-#endif
-	.o = {
-		.item_ops = &stat40_ops
-	}
-};
-
-static reiser4_plug_t *stat40_start(reiser4_core_t *c) {
-	stat40_core = c;
-	return &stat40_plug;
-}
-
-plug_register(stat40, stat40_start, NULL);
-
