@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    sdext_lw.h -- stat data plugin, that implements base stat data fields. */
@@ -9,13 +9,11 @@
 #include <aal/libaal.h>
 #include <reiser4/plugin.h>
 
-struct sdext_lw {
+typedef struct sdext_lw {
 	d16_t mode;
 	d32_t nlink;
 	d64_t size;
-} __attribute__((packed));
-
-typedef struct sdext_lw sdext_lw_t;
+} __attribute__((packed)) sdext_lw_t;
 
 extern reiser4_core_t *sdext_lw_core;
 
