@@ -319,7 +319,8 @@ int main(int argc, char *argv[]) {
 			    hint.blocks != 0)
 			{
 				aal_error("Filesystem length is already "
-					  "set to %llu.", hint.blocks);
+					  "set to %llu.",
+					  (unsigned long long)hint.blocks);
 				continue;
 			}
 			
@@ -422,7 +423,8 @@ int main(int argc, char *argv[]) {
 		if (hint.blocks > dev_len) {
 			aal_error("Filesystem wouldn't fit into device "
 				  "%llu blocks long, %llu blocks required.",
-				  dev_len, hint.blocks);
+				  (unsigned long long)dev_len,
+				  (unsigned long long)hint.blocks);
 			goto error_free_device;
 		}
 
